'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var React = require('react');
var moment = require('moment');
var _ = require('underscore');
var Day = require('./Day').Day;

var propTypes = {
  year: React.PropTypes.number.isRequired,
  forceFullWeeks: React.PropTypes.bool,
  showDaysOfWeek: React.PropTypes.bool,
  onPickDate: React.PropTypes.func
};

var defaultProps = {
  year: moment().year(),
  forceFullWeeks: false,
  showDaysOfWeek: true,
  onPickDate: null,
  selectedDay: moment()
};

var Calendar = exports.Calendar = (function (_React$Component) {
  _inherits(Calendar, _React$Component);

  function Calendar(props) {
    _classCallCheck(this, Calendar);

    return _possibleConstructorReturn(this, Object.getPrototypeOf(Calendar).call(this, props));
  }

  _createClass(Calendar, [{
    key: 'monthDays',
    value: function monthDays(month) {
      var _this2 = this;

      var monthStart = moment([this.props.year, month, 1]); // current day

      // number of days to insert before the first of the month to correctly align the weekdays
      var prevMonthDaysCount = monthStart.weekday();
      // days in month
      var numberOfDays = monthStart.daysInMonth();
      // insert days at the end to match up 37 (max number of days in a month + 6)
      // or 42 (if user prefers seeing the week closing with Sunday)
      var totalDays = this.props.forceFullWeeks ? 42 : 37;

      // day-generating loop
      return _.range(1, totalDays + 1).map(function (i) {
        var day = moment([_this2.props.year, month, i - prevMonthDaysCount]);

        // pick appropriate classes
        var classes = [];
        if (i <= prevMonthDaysCount) {
          classes.push('prev-month');
        } else if (i > numberOfDays + prevMonthDaysCount) {
          classes.push('next-month');
        } else {
          // 'selected' class sholud be applied only to days in this month
          if (day.isSame(_this2.props.selectedDay, 'day')) {
            classes.push('selected');
          }
        }

        if ((i - 1) % 7 == 0) {
          classes.push('bolder');
        }

        return React.createElement(Day, {
          key: 'day-' + i,
          day: day,
          classes: classes.join(' '),
          onClick: _this2.props.onPickDate
        });
      });
    }
  }, {
    key: 'monthName',
    value: function monthName(month) {
      var date = moment([this.props.year, month, 1]);

      return date.format('MMM');
    }
  }, {
    key: 'daysOfWeek',
    value: function daysOfWeek() {
      var daysOfWeek = [];
      var totalDays = this.props.forceFullWeeks ? 42 : 37;
      for (var i = 0; i < totalDays; i++) {
        daysOfWeek.push(moment().weekday(i).format('dd').charAt(0));
      }

      return daysOfWeek;
    }
  }, {
    key: 'render',
    value: function render() {
      var _this3 = this;

      var weekDays = undefined;
      if (this.props.showDaysOfWeek) {
        weekDays = React.createElement(
          'tr',
          null,
          React.createElement(
            'th',
            null,
            ' '
          ),
          this.daysOfWeek().map(function (day, i) {
            return React.createElement(
              'th',
              {
                key: 'weekday-' + i,
                className: i % 7 == 0 ? 'bolder' : ''
              },
              day
            );
          })
        );
      }

      var months = _.range(0, 12).map(function (month, i) {
        return React.createElement(
          'tr',
          { key: 'month' + i },
          React.createElement(
            'td',
            { className: 'month-name' },
            _this3.monthName(month)
          ),
          _this3.monthDays(month)
        );
      });

      return React.createElement(
        'table',
        { className: 'calendar' },
        React.createElement(
          'thead',
          { className: 'day-headers' },
          weekDays
        ),
        React.createElement(
          'tbody',
          null,
          months
        )
      );
    }
  }]);

  return Calendar;
})(React.Component);

Calendar.propTypes = propTypes;
Calendar.defaultProps = defaultProps;